# Zope3 imports
from zope.interface import implements

# CMF imports
from Products.CMFCore import permissions

# Archetypes & ATCT imports
from Products.Archetypes import atapi
from Products.ATContentTypes.content import base
from Products.ATContentTypes.content import schemata

# Product imports
from plone.tournament import _, PROJECTNAME
from plone.tournament.interfaces import IGame

from itertools import imap, ifilter
from operator import methodcaller

# Schema definition
schema = atapi.BaseSchema + atapi.Schema((
    atapi.ComputedField('title',
       searchable=1,
       expression='context._composeTitle()',
       accessor='Title'
    ),

    atapi.ReferenceField('home_team',
           required=1,
           relationship='hosted_by',
           allowed_types=('plone.tournament.Team',),
           widget = atapi.ReferenceWidget(
               label = _(u'Home team'),
               description = _(u''),
               checkbox_bound = 0,
           ),

    ),

    atapi.IntegerField('home_score',
        widget = atapi.StringWidget(
            label = _(u'Home score'),
            description = _(u''),
        ),
    ),

    atapi.ReferenceField('guest_team',
           required=1,
           relationship='joined_by',
           allowed_types=('plone.tournament.Team',),
           widget = atapi.ReferenceWidget(
               label = _(u'Guest team'),
               description = _(u''),
               checkbox_bound = 0,
           ),
    ),

    atapi.IntegerField('guest_score',
        widget = atapi.StringWidget(
            label = _(u'Guest score'),
            description = _(u''),
        ),
     ),

     atapi.DateTimeField('start',
        widget = atapi.CalendarWidget(
            label = _(u'Start date'),
            description = _(u''),
        ),
     ),

))


class Game(base.ATCTContent):
    """An Archetype for Team application"""

    implements(IGame)

    schema = schema
    
    def _composeTitle(self):
        """Compose object's Title"""
        teams = (self.getHome_team(), self.getGuest_team())
        return " - ".join(imap(methodcaller('Title'), ifilter(None, teams)))

# Content type registration for the Archetypes machinery
atapi.registerType(Game, PROJECTNAME)
